from gi.repository import Gtk, Adw
from whatip.confManager import ConfManager
from whatip.headerbar import GHeaderbar
from whatip.main_stack import MainStack


class AppWindow(Adw.ApplicationWindow):
    def __init__(self, **kwargs):
        super().__init__(**kwargs)
        self.confman = ConfManager()

        self.set_title('What IP')
        self.set_icon_name('org.gabmus.whatip')

        self.main_box = Gtk.Box(orientation=Gtk.Orientation.VERTICAL)
        self.main_stack = MainStack()
        self.main_stack.connect(
            'notify::visible-child',
            self.on_main_stack_change
        )
        self.bottom_bar = Adw.ViewSwitcherBar()
        self.bottom_bar.set_stack(self.main_stack)

        self.iface_listbox = self.main_stack.ip_listbox
        self.headerbar = GHeaderbar(self.main_stack)
        self.on_main_stack_change()  # sets text to current stack child
        self.headerbar.connect('headerbar_squeeze', self.on_headerbar_squeeze)

        self.main_box.append(self.headerbar)
        self.headerbar.set_vexpand(False)
        self.main_box.append(self.main_stack)
        self.main_stack.set_vexpand(True)
        self.main_box.append(self.bottom_bar)
        self.bottom_bar.set_vexpand(False)

        self.set_child(self.main_box)

        self.set_default_size(
            self.confman.conf['windowsize']['width'],
            self.confman.conf['windowsize']['height']
        )

        shortcuts_l = [
            {
                'combo': 'F10',
                'cb': self.toggle_menu
            }
        ]
        self.shortcut_controller = Gtk.ShortcutController()
        self.shortcut_controller.set_scope(Gtk.ShortcutScope.GLOBAL)
        for s in shortcuts_l:
            self.add_accelerator(s['combo'], s['cb'])
        self.add_controller(self.shortcut_controller)

    def toggle_menu(self, *args):
        popover = self.headerbar.menu_btn.get_popover()
        if popover.get_visible():
            popover.popdown()
        else:
            popover.popup()

    def on_main_stack_change(self, *args):
        self.headerbar.nobox.set_text(
            self.main_stack.get_visible_child_name()
        )

    def on_headerbar_squeeze(self, caller, squeezed):
        self.bottom_bar.set_reveal(squeezed)

    def add_accelerator(self, shortcut, callback):
        if shortcut:
            # res is bool, don't know what it is
            res, key, mod = Gtk.accelerator_parse(shortcut)
            trigger = Gtk.KeyvalTrigger.new(key, mod)
            cb = Gtk.CallbackAction.new(callback)
            shortcut = Gtk.Shortcut.new(trigger, cb)
            self.shortcut_controller.add_shortcut(shortcut)

    def emit_destroy(self, *args):
        self.emit('close-request')

    def on_destroy(self, *args):
        alloc = self.get_allocation()
        self.confman.conf['windowsize'] = {
            'width': alloc.width,
            'height': alloc.height
        }
        self.confman.save_conf()

    def do_startup(self):
        self.headerbar.on_refresh_btn_clicked()
