from gi.repository import Gtk
from whatip.network_interface import NetworkInterface
from gettext import gettext as _
from whatip.clipboard_helper import clipboard_copy


class NetworkInterfaceListboxRow(Gtk.ListBoxRow):
    NET_ICONS = {
        NetworkInterface.INTERNET: 'globe-symbolic',
        NetworkInterface.WIRED: 'network-wired-symbolic',
        NetworkInterface.WIRELESS: 'network-wireless-symbolic',
        NetworkInterface.MOBILE: 'phone-symbolic',
        NetworkInterface.VIRTUAL_BRIDGE: 'bridge-symbolic',
        NetworkInterface.TUNNEL: 'network-vpn-symbolic',
        NetworkInterface.LOOPBACK: 'media-playlist-repeat-symbolic',
        NetworkInterface.WIREGUARD: 'network-vpn-symbolic',
        NetworkInterface.UNKNOWN: 'dialog-question-symbolic'
    }
    NET_NAMES = {
        NetworkInterface.INTERNET: _('Public Internet'),
        NetworkInterface.WIRED: _('Wired'),
        NetworkInterface.WIRELESS: _('Wireless'),
        NetworkInterface.MOBILE: _('Mobile'),
        NetworkInterface.VIRTUAL_BRIDGE: _('Virtual bridge'),
        NetworkInterface.TUNNEL: _('Tunnel'),
        NetworkInterface.LOOPBACK: _('Loopback'),
        NetworkInterface.WIREGUARD: _('WireGuard'),
        NetworkInterface.UNKNOWN: _('Unknown')
    }

    def __init__(self, net_iface: NetworkInterface, *args, **kwargs):
        super().__init__(*args, **kwargs)
        # self.get_style_context().add_class('card')
        self.net_iface = net_iface
        self.builder = Gtk.Builder.new_from_resource(
            '/org/gabmus/whatip/ui/net_iface_listbox_row.glade'
        )
        self.mainbox = self.builder.get_object('mainbox')
        self.icon = self.builder.get_object('icon')
        self.icon.set_from_icon_name(
            NetworkInterfaceListboxRow.NET_ICONS[
                self.net_iface.interface_type
            ]
        )
        self.icon.set_tooltip_text(
            NetworkInterfaceListboxRow.NET_NAMES[
                self.net_iface.interface_type
            ]
        )
        self.addr_label = self.builder.get_object('address_label')
        self.ipv6_box = self.builder.get_object('ipv6_box')
        self.inet6_addr_label = self.builder.get_object('inet6_address_label')
        self.interface_label = self.builder.get_object('interface_label')

        self.addr_label.set_text(self.net_iface.address)

        if (hasattr(self.net_iface, 'inet6_address')):
            self.inet6_addr_label.set_text(self.net_iface.inet6_address)
        else:
            self.ipv6_box.set_visible(False)

        self.interface_label.set_text(
            '{0}{1}'.format(
                NetworkInterfaceListboxRow.NET_NAMES[
                    self.net_iface.interface_type
                ] + ': '
                if self.net_iface.interface_type != NetworkInterface.INTERNET
                else '',
                self.net_iface.interface
            )
        )

        self.location_label = self.builder.get_object('location_label')
        if self.net_iface.location is not None:
            if self.net_iface.location['region'] is not None:
                self.location_label.set_text(_('{0}, {1} - {2}').format(
                    self.net_iface.location['city'],
                    self.net_iface.location['region'],
                    self.net_iface.location['country']
                ))
            else:
                self.location_label.set_text(_('{0} - {1}').format(
                    self.net_iface.location['city'],
                    self.net_iface.location['country']
                ))
            self.location_label.set_visible(True)
        else:
            self.location_label.set_visible(False)

        self.copy_btn = self.builder.get_object('copy_btn')
        self.copy_btn.connect(
            'clicked', lambda *args: clipboard_copy(
                self.net_iface.address
            )
        )

        self.copy_ipv6_btn = self.builder.get_object('copy_ipv6_btn')
        self.copy_ipv6_btn.connect(
            'clicked', lambda *args: clipboard_copy(
                self.net_iface.inet6_address
            )
        )

        self.set_child(self.mainbox)
